/**
 * AppLovin PhoneGap Plugin
 *
 * @author David Anderson, Matt Szaro
 * @version 1.3
 */

if (typeof(AppLovin) == 'undefined') {
    var AppLovin = {
        /**
    	 * Loads an AppLovin ad into the specified iframe
    	 *
    	 * @param {String} id  Element id for the iframe to display the ad in.
    	 */
    	loadNextAd : function(iframeId) {
			var iframe = document.getElementById(iframeId);
			
    		var frameClass = "applovin_" + AppLovin.randomString();
    		iframe.setAttribute("class", frameClass);

            AppLovin.exec('loadNextAd', [ frameClass, iframeId ]);
    	},
    	
    	freeAd: function(iframeId) {
    		var iframe = document.getElementById(iframeId);
    		var frameClass = iframe.getAttribute("class");
    		
    		AppLovin.exec('freeAd', [ frameClass ]);
    	},
    	
    	/**
    	 * Displays an Interstitial Ad
    	 */
    	showInterstitial : function() {
            AppLovin.exec('showInterstitial', []);
    	},
    	
    	/**
    	 * Initializes the SDK
    	 */
    	initializeSdk : function() {
            AppLovin.exec('initializeSdk', []);
    	},
    	
    	/**
    	 * Generates random string. This method is for internal use only.
    	 */
    	randomString : function() {
    	    var chars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXTZabcdefghiklmnopqrstuvwxyz";

    	    var string_length = 8;
    	    var randomstring = '';
    	    for (var i=0; i<string_length; i++) {
    		var rnum = Math.floor(Math.random() * chars.length);
    		randomstring += chars.substring(rnum,rnum+1);
    	    }
    	    
    	    return randomstring;
    	},
    	
    	/**
    	 * Track a click on an advertisement. This method is for internal use only.
    	 */
    	trackClick : function(frameClass) {
            AppLovin.exec('clickTrack', [frameClass]);
    	},
    	
        /**
    	 * Render an advertisement in a given iframe. This method is for internal use only.
    	 */
    	renderAd : function(frameClass, html) {
			var iframe = document.getElementsByClassName(frameClass);
			iframe = iframe[0];
    		ifrm = (iframe.contentWindow) ? iframe.contentWindow : (iframe.contentDocument.document) ? iframe.contentDocument.document : iframe.contentDocument;
    		var cleanHtml = html['html'].replace("applovin://", "#");
    		ifrm.document.open();
    		ifrm.document.write(cleanHtml);
    		ifrm.document.close();
    		
    		ifrm.document.addEventListener('click', function(event) {AppLovin.trackClick(frameClass);}, false);
    
    		iframe.style.display = 'block';
    	},
    	
    	/**
    	 * Autoloads an Ad where script is placed in the body tag. This method is for internal use only.
    	 */
    	autoload : function() {
    	    var tempId = "applovin_temp_" + AppLovin.randomString();
    	    document.write('<script id="' + tempId + '"></script>');
	    
    	    var head = document.getElementsByTagName('head')[0];    	    
    	    var meta = document.getElementById(tempId);
    	    
    	    if (head.innerHTML.indexOf(tempId) > -1) {
    	        if (meta && typeof(meta.parentNode) != 'undefined') {
					meta.parentNode.removeChild(meta);
				} 
     	    } else {
				if (meta && typeof(meta.parentNode) != 'undefined') {	    
	    			meta.parentNode.removeChild(meta);
	    		}
    	    
     	    	var frameId = "applovin_" + AppLovin.randomString();
	        	document.write('<iframe id="' + frameId + '" style="display: none; width: 100%; height: 50px; border: 0;"></iframe>');
	        	
	    		if ((typeof(cordova) != 'undefined' && typeof(cordova.exec) == 'undefined') || (typeof(PhoneGap) != 'undefined' && typeof(PhoneGap.exec) == 'undefined')) {
	    		    document.addEventListener("deviceready", function() {AppLovin.loadNextAd(frameId);}, false);
	    		} else {
	    		    AppLovin.loadNextAd(frameId);
	    		}
    	    }
    	},
    	
    	exec : function(call, params) {
			if (typeof(cordova) != 'undefined') {
    			cordova.exec(function() {}, function() {}, "AppLovin", call, params);
    	    } else {
    			PhoneGap.exec(function() {}, function() {}, "AppLovin", call, params);  
    	    }
    	},
    	
    	TargetingData: {
	    	GENDER_MALE   : "m",
	    	GENDER_FEMALE : "f",
	    	
	    	ETHNICITY_MIXED : "mixed",
	    	ETHNICITY_ASIAN : "asian",
	    	ETHNICITY_BLACK : "black",
	    	ETHNICITY_HISPANIC : "hispanic",
	    	ETHNICITY_NATIVE_AMERICAN : "native_american",
	    	ETHNICITY_WHITE : "white",
	    	ETHNICITY_OTHER : "other",
	    	
	    	MARITAL_STATUS_SINGLE : "single",
	    	MARITAL_STATUS_MARRIED : "married",
	    	MARITAL_STATUS_DIVORCED : "divorced",
	    	MARITAL_STATUS_WIDOWED : "widowed",
	    	
	    	EDUCATION_HIGH_SCHOOL : "high_school",
	    	EDUCATION_COLLEGE : "college",
	    	EDUCATION_BACHELORS : "bachelors",
	    	EDUCATION_MASTERS : "masters",
	    	EDUCATION_DOCTORAL : "doctoral",
	    	EDUCATION_OTHER : "other",
	    	 
			/**
			 * Set the current user's gender
			 * 
			 * @param {string} gender  The current user's gender
			 */
			setGender : function(gender) {
				AppLovin.exec('setGender', [gender]);
			},
			
			/**
			 * Set the current user's phone number
			 * 
			 * @param {string} phoneNumber  The current user's phone number
			 */
			setPhoneNumber : function(phoneNumber) {
				AppLovin.exec('setPhoneNumber', [phoneNumber]);
			},
			
			/**
			 * Set the current user's year of birth
			 * 
			 * @param {int} birthYear  The current user's year of birth
			 */
			setBirthYear : function(birthYear) {
				AppLovin.exec('setBirthYear', [birthYear]);
			},
			
			/**
			 * Set the current user's language
			 * 
			 * @param {string} language  The current user's language
			 */
			setLanguage : function(language) {
				AppLovin.exec('setLanguage', [language]);
			},
			
			/**
			 * Set the current user's country
			 * 
			 * @param {string} country  The current user's country
			 */
			setCountry : function(country) {
				AppLovin.exec('setCountry', [country]);
			},
			
			/**
			 * Set the current user's first name
			 * 
			 * @param {string} firstName  The current user's first name
			 */
			setFirstName : function(firstName) {
				AppLovin.exec('setFirstName', [firstName]);
			},
			
			/**
			 * Set the current user's carrier
			 * 
			 * @param {string} carrier  The current user's carrier
			 */
			setCarrier : function(carrier) {
				AppLovin.exec('setCarrier', [carrier]);
			},
			
			/**
			 * Set the current user's email
			 * 
			 * @param {string} email  The current user's email
			 */
			setEmail : function(email) {
				AppLovin.exec('setEmail', [email]);
			},
			
			/**
			 * Set the current user's income
			 * 
			 * @param {string} income  The current user's income
			 */
			setIncome : function(income) {
				AppLovin.exec('setIncome', [income]);
			},
			
			/**
			 * Set the current user's marital status
			 * 
			 * @param {string} marital  The current user's marital status
			 */
			setMaritalStatus : function(marital) {
				AppLovin.exec('setMaritalStatus', [marital]);
			},
			
			/**
			 * Set the current user's education
			 * 
			 * @param {string} education  The current user's education
			 */
			setEducation : function(education) {
				AppLovin.exec('setEducation', [education]);
			},
			
			/**
			 * Set the current user's ethnicity
			 * 
			 * @param {string} ethnicity  The current user's ethnicity
			 */
			setEthnicity : function(ethnicity) {
				AppLovin.exec('setEthnicity', [ethnicity]);
			},
			
			/**
			 * Set the current user's emails
			 * 
			 * @param {string[]} emails  The current user's emails
			 */
			setEmails : function(emails) {
				AppLovin.exec('setEmails', emails);
			},
			
			/*
			 * Set the current user's interests
			 * 
			 * @param {string[]} interests  The current user's interests
			 */
			setInterests : function(interests) {
				AppLovin.exec('setInterests', interests);
			},
			
			/**
			 * Set the keywords for the current app
			 * 
			 * @param {params string[]} keywords  Some keywords for the current app
			 */
			setKeywords : function(keywords) {
				AppLovin.exec('setKeywords', keywords);
			},
			
			/**
			 * Set extra parameter for ad requests
			 * 
			 * @param {string} key  Key of the parameter
			 * @param {string} val  Value of the parameter
			 */
			putExtra : function(key, val) {
				AppLovin.exec('putExtra', [key, val]);
			}
		}
    };
    
    if ((typeof(cordova) != 'undefined' && typeof(cordova.exec) == 'undefined') || (typeof(PhoneGap) != 'undefined' && typeof(PhoneGap.exec) == 'undefined')) {
	    document.addEventListener("deviceready", function() {AppLovin.initializeSdk();}, false);
	} else {
	    AppLovin.initializeSdk();
	}
}

AppLovin.autoload();